Skip to contents

A data frame with 8487 rows and 4 columns, containing all the votes cast for every tagging proposal in proposals, generated by get_proposals_votes().

Usage

proposals_votes

Format

columns:

url

(string) the URL to the tagging proposal wiki page.

votes_raw

a string with the wiki page containing the proposal.

vote

(factor) vote type (approve, abstain, oppose).

user

(factor) voter's username