A data frame with 8487 rows and 4 columns, containing all
the votes cast for every tagging proposal in proposals, generated by get_proposals_votes().
A data frame with 8487 rows and 4 columns, containing all
the votes cast for every tagging proposal in proposals, generated by get_proposals_votes().